#!/bin/sh

# Author Michael Green, Programming Research.
# Date : 25 Sep 2002

# The lmutil program will run a command passed as the first paramater.
# The lmutil program will assume the command from a link name.
# See Section 6.1 Running Administration Tools in the enduser.pdf 

rm -f lmhostid lmver lmdown lmremove lmreread lmswitchr \
    lmstat lmdiag lminstall lmpath lmborrow lmswitch

ln lmutil lmhostid
ln lmutil lmver
ln lmutil lmdown
ln lmutil lmremove 
ln lmutil lmreread 
ln lmutil lmswitchr 
ln lmutil lmstat 
ln lmutil lmdiag
ln lmutil lminstall
ln lmutil lmpath
ln lmutil lmborrow
ln lmutil lmswitch

